###################
Scientific articles
###################
Please consider citing the following article when using MDT in your research:

.. bibliography:: references.bib
    :all:
    :list: bullet
    :filter: author % "Harms"

